Merge pull request #363 from hugovk/add-3.11

Add support for Python 3.11
diff --git a/colorama/winterm.py b/colorama/winterm.py
index aad867e..d58b52b 100644
--- a/colorama/winterm.py
+++ b/colorama/winterm.py
@@ -190,6 +190,6 @@
         mode = win32.GetConsoleMode(handle)
         if mode & win32.ENABLE_VIRTUAL_TERMINAL_PROCESSING:
             return True
-    # Can get TypeError in testsuite where 'fd' is a Mock()
-    except (OSError, TypeError):
+    # Can get TypeError in testsuite where 'fd' is a Mock() and IOError in python2.7
+    except (IOError, OSError, TypeError):
         return False